<?php
namespace MeetTheTeam;

define( "TEST_ASFSK_ASSETS_ADMIN_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/admin" );
class MeetTheTeam {

	private static $_instance = null;

	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	public function mtt_admin_editor_scripts() {
		add_filter( 'script_loader_tag', [ $this, 'mtt_admin_editor_scripts_as_a_module' ], 10, 2 );
	}

	public function mtt_admin_editor_scripts_as_a_module( $tag, $handle ) {
		if ( 'mtt_meet_the_team_editor' === $handle ) {
			$tag = str_replace( '<script', '<script type="module"', $tag );
		}

		return $tag;
	}

	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/team-mtt.php' );
		require_once( __DIR__ . '/widgets/team-mtt-carousel.php' );
	}

	public function mtt_register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files();

		// Register WidgetsF
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\MTTMeetTheTeam() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\MTTMeetTheTeamCarousel() );
	}

	// Register Category
	public function mtt_add_elementor_widget_categories( $elements_manager ) {

		$elements_manager->add_category(
			'meet-the-team-category',
			[
				'title' => esc_html__( 'Meet The Team', 'meet-the-team' ),
				'icon' => 'eicon-person',
			]
		);
	}
	public function mtt_all_assets_for_the_public(){
		$mtt_cnd_link = 'https://bwd-elementor-addons-pro.netlify.app/meet-the-team/';
		wp_enqueue_script( 'mtt_the_js_slick', $mtt_cnd_link.'slick.min.js', array('jquery'), '2.1', true );
		wp_enqueue_script( 'mtt_the_js_min', $mtt_cnd_link.'min.js', array('jquery'), '2.1', true );
		$all_css_js_file = array(
            'mtt_team_plugin_main_css' => array('mtt_path_define'=>$mtt_cnd_link.'mtt-team-main.css'),
            'mtt_team_plugin_responsive_col' => array('mtt_path_define'=>'https://bwd-elementor-addons-pro.netlify.app/responsive-column.css'),
            'mtt_team_plugin_slick_css' => array('mtt_path_define'=>$mtt_cnd_link.'slick.css'),
            'mtt_team_plugin_font_awesome' => array('mtt_path_define'=>'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.0/css/all.min.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['mtt_path_define'], null, '2.1', 'all');
        }
	}
	public function mtt_all_assets_for_elementor_editor_admin(){
		$all_css_js_file = array(
            'mtt_team_admin_main_css' => array('mtt_path_admin_define'=>TEST_ASFSK_ASSETS_ADMIN_DIR_FILE . '/icon.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['mtt_path_admin_define'], null, '2.1', 'all');
        }
	}
	
	public function __construct() {

		// For public assets
		add_action('wp_enqueue_scripts', [$this, 'mtt_all_assets_for_the_public']);

		// For Elementor Editor
		add_action('elementor/editor/before_enqueue_scripts', [$this, 'mtt_all_assets_for_elementor_editor_admin']);
		
		// Register Category
		add_action( 'elementor/elements/categories_registered', [ $this, 'mtt_add_elementor_widget_categories' ] );

		// Register widgets
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'mtt_register_widgets' ] );

		// Register editor scripts
		add_action( 'elementor/editor/after_enqueue_scripts', [ $this, 'mtt_admin_editor_scripts' ] );
	}
}

// Instantiate Plugin Class
MeetTheTeam::instance();