<?php
namespace MeetTheTeam\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class MTTMeetTheTeam extends Widget_Base {

	public function get_name() {
		return esc_html__( 'MeetTheTeam', 'meet-the-team' );
	}

	public function get_title() {
		return esc_html__( 'Meet The Team', 'elementor' );
	}

	public function get_icon() {
		return 'mtt-ua-icon eicon-person';
	}

	public function get_categories() {
		return [ 'meet-the-team-category' ];
	}

	public function get_script_depends() {
		return [ 'meet-the-team-category' ];
	}

	protected function register_controls() {
		$this->start_controls_section(
			'text_content_section',
			[
				'label' => esc_html__( 'Team Content', 'meet-the-team' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'mtt_style_selection',
			[
				'label' => esc_html__( 'Team Style', 'meet-the-team' ),
				'type' => Controls_Manager::SELECT,
				'default' => '1',
				'options' => [
					'1'  => esc_html__( 'Style 1', 'meet-the-team' ),
					'2' => esc_html__( 'Style 2', 'meet-the-team' ),
					'3' => esc_html__( 'Style 3', 'meet-the-team' ),
					'4' => esc_html__( 'Style 4', 'meet-the-team' ),
					'5' => esc_html__( 'Style 5', 'meet-the-team' ),
					'6' => esc_html__( 'Style 6', 'meet-the-team' ),
					'7' => esc_html__( 'Style 7', 'meet-the-team' ),
					'8' => esc_html__( 'Style 8', 'meet-the-team' ),
					'9' => esc_html__( 'Style 9', 'meet-the-team' ),
					'10' => esc_html__( 'Style 10', 'meet-the-team' ),
					'11' => esc_html__( 'Style 11', 'meet-the-team' ),
					'12' => esc_html__( 'Style 12', 'meet-the-team' ),
					'13' => esc_html__( 'Style 13', 'meet-the-team' ),
					'14' => esc_html__( 'Style 14', 'meet-the-team' ),
					'15' => esc_html__( 'Style 15', 'meet-the-team' ),
					'16' => esc_html__( 'Style 16', 'meet-the-team' ),
					'17' => esc_html__( 'Style 17', 'meet-the-team' ),
					'18' => esc_html__( 'Style 18', 'meet-the-team' ),
					'19' => esc_html__( 'Style 19', 'meet-the-team' ),
					'20' => esc_html__( 'Style 20', 'meet-the-team' ),
					'21' => esc_html__( 'Style 21', 'meet-the-team' ),
					'22' => esc_html__( 'Style 22', 'meet-the-team' ),
					'23' => esc_html__( 'Style 23', 'meet-the-team' ),
					'24' => esc_html__( 'Style 24', 'meet-the-team' ),
					'25' => esc_html__( 'Style 25', 'meet-the-team' ),
					'26' => esc_html__( 'Style 26', 'meet-the-team' ),
					'27' => esc_html__( 'Style 27', 'meet-the-team' ),
					'28' => esc_html__( 'Style 28', 'meet-the-team' ),
					'29' => esc_html__( 'Style 29', 'meet-the-team' ),
					'30' => esc_html__( 'Style 30', 'meet-the-team' ),
					'31' => esc_html__( 'Style 31', 'meet-the-team' ),
				],
			]
		);
		$this->add_responsive_control(
			'mtt_team_box_align',
			[
				'label' => esc_html__( 'Column Alignment', 'meet-the-team' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'flex-start' => [
						'title' => esc_html__( 'Left', 'meet-the-team' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'meet-the-team' ),
						'icon' => 'eicon-text-align-center',
					],
					'flex-end' => [
						'title' => esc_html__( 'Right', 'meet-the-team' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'default' => 'flex-start',
				'selectors' => [
					'{{WRAPPER}} .bwd-row' => 'justify-content: {{VALUE}};',
				],
			]
		);
		$this->add_responsive_control(
			'mtt_column_layout',
			[
				'label' => esc_html__( 'Choose Column', 'meet-the-team' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'default',
				'options' => [
					'default' => esc_html__( 'Default', 'meet-the-team' ),
					'column1' => esc_html__( '1 Column', 'meet-the-team' ),
					'column2' => esc_html__( '2 Column', 'meet-the-team' ),
					'column3'  => esc_html__( '3 Column', 'meet-the-team' ),
                    'column4' => esc_html__( '4 Column', 'meet-the-team' ),
                    'column5' => esc_html__( '5 Column', 'meet-the-team' ),
                    'column6' => esc_html__( '6 Column', 'meet-the-team' ),
				],
				'prefix_class' => 'mtt-grid%s-'
			]
		);
		$this->add_responsive_control(
			'mtt_column_gap',
			[
				'label' => esc_html__( 'Column Gap', 'meet-the-team' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'default' => [
					'unit' => 'px',
					'size' => 15,
				],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 300,
						'step' => 1,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .mtt_gapc' => 'padding-inline-start: {{SIZE}}{{UNIT}}; padding-inline-end: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .mtt_gapr' => 'margin-inline-start: -{{SIZE}}{{UNIT}}; margin-inline-end: -{{SIZE}}{{UNIT}};',
				],
			]
		);
		$this->add_responsive_control(
			'mtt_row_gap',
			[
				'label' => esc_html__( 'Row Gap', 'meet-the-team' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'default' => [
					'unit' => 'px',
					'size' => 30,
				],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 300,
						'step' => 1,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .mtt-total-team-box' => 'margin-block-end: {{SIZE}}{{UNIT}};',
				],
			]
		);
		
		$this->end_controls_section();
		
		$this->start_controls_section(
			'mtt_flipflop_step_content_box_section',
			[
				'label' => esc_html__( 'Team Boxes', 'meet-the-team' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		$repeater = new \Elementor\Repeater();

		// Content Tab

		$repeater->start_controls_tabs(
			'style_tabs'
		);
		$repeater->start_controls_tab(
			'mtt_style_normal_tab',
			[
				'label' => esc_html__( 'Normal', 'meet-the-team' ),
			]
		);
		$repeater->add_control(
			'mtt_box_name', [
				'label' => esc_html__( 'Name', 'meet-the-team' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__( 'JHON DOE' , 'meet-the-team' ),
				'dynamic' => [
					'active' => true,
				],
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'mtt_box_designation', [
				'label' => esc_html__( 'Designation', 'meet-the-team' ),
				'type' => Controls_Manager::WYSIWYG,
				'default' => esc_html__( 'Web Developer' , 'meet-the-team' ),
				'dynamic' => [
					'active' => true,
				],
			]
		);
		$repeater->add_control(
			'mtt_team_profile_image',
			[
				'label' => esc_html__( 'Choose Profile Image', 'meet-the-team' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => 'https://bwd-elementor-addons-pro.netlify.app/bwd-placeholder.jpg',
				],
			]
		);
		$repeater->add_control(
			'mtt_social_icon_one_switcher',
			[
				'label' => esc_html__( 'Social Icon One', 'meet-the-team' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'meet-the-team' ),
				'label_off' => esc_html__( 'Hide', 'meet-the-team' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);
		$repeater->add_control(
			'mtt_social_icon_one',
			[
				'type' => Controls_Manager::ICONS,
				'skin' => 'inline',
				'default' => [
					'value' => 'fab fa-facebook-f',
					'library' => 'solid',
				],
				'condition' => [
					'mtt_social_icon_one_switcher' => 'yes',
				],
			]
		);
		$repeater->add_control(
			'mtt_social_icon_one_link',
			[
				'label' => esc_html__( 'Link', 'meet-the-team' ),
				'type' => Controls_Manager::URL,
				'condition' => [
					'mtt_social_icon_one_switcher' => 'yes',
				],
				'placeholder' => esc_html__( 'your-link.com', 'meet-the-team' ),
				'default' => [
					'url' => 'www.facebook.com',
					'is_external' => true,
					'nofollow' => true,
					'custom_attributes' => '',
				],
			]
		);
		$repeater->add_control(
			'mtt_social_icon_two_switcher',
			[
				'label' => esc_html__( 'Social Icon Two', 'meet-the-team' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'meet-the-team' ),
				'label_off' => esc_html__( 'Hide', 'meet-the-team' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);
		$repeater->add_control(
			'mtt_social_icon_two',
			[
				'type' => Controls_Manager::ICONS,
				'skin' => 'inline',
				'default' => [
					'value' => 'fab fa-twitter',
					'library' => 'solid',
				],
				'condition' => [
					'mtt_social_icon_two_switcher' => 'yes',
				],
			]
		);
		$repeater->add_control(
			'mtt_social_icon_two_link',
			[
				'label' => esc_html__( 'Link', 'meet-the-team' ),
				'type' => Controls_Manager::URL,
				'condition' => [
					'mtt_social_icon_two_switcher' => 'yes',
				],
				'placeholder' => esc_html__( 'your-link.com', 'meet-the-team' ),
				'default' => [
					'url' => 'www.twitter.com',
					'is_external' => true,
					'nofollow' => true,
					'custom_attributes' => '',
				],
			]
		);
		$repeater->add_control(
			'mtt_social_icon_three_switcher',
			[
				'label' => esc_html__( 'Social Icon Three', 'meet-the-team' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'meet-the-team' ),
				'label_off' => esc_html__( 'Hide', 'meet-the-team' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);
		$repeater->add_control(
			'mtt_social_icon_three',
			[
				'type' => Controls_Manager::ICONS,
				'skin' => 'inline',
				'default' => [
					'value' => 'fab fa-linkedin-in',
					'library' => 'solid',
				],
				'condition' => [
					'mtt_social_icon_three_switcher' => 'yes',
				],
			]
		);
		$repeater->add_control(
			'mtt_social_icon_three_link',
			[
				'label' => esc_html__( 'Link', 'meet-the-team' ),
				'type' => Controls_Manager::URL,
				'condition' => [
					'mtt_social_icon_three_switcher' => 'yes',
				],
				'placeholder' => esc_html__( 'your-link.com', 'meet-the-team' ),
				'default' => [
					'url' => 'www.linkedin.com',
					'is_external' => true,
					'nofollow' => true,
					'custom_attributes' => '',
				],
			]
		);
		$repeater->add_control(
			'mtt_social_icon_four_switcher',
			[
				'label' => esc_html__( 'Social Icon Four', 'meet-the-team' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'meet-the-team' ),
				'label_off' => esc_html__( 'Hide', 'meet-the-team' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);
		$repeater->add_control(
			'mtt_social_icon_four',
			[
				'type' => Controls_Manager::ICONS,
				'skin' => 'inline',
				'default' => [
					'value' => 'fab fa-instagram',
					'library' => 'solid',
				],
				'condition' => [
					'mtt_social_icon_four_switcher' => 'yes',
				],
			]
		);
		$repeater->add_control(
			'mtt_social_icon_four_link',
			[
				'label' => esc_html__( 'Link', 'meet-the-team' ),
				'type' => Controls_Manager::URL,
				'condition' => [
					'mtt_social_icon_four_switcher' => 'yes',
				],
				'placeholder' => esc_html__( 'your-link.com', 'meet-the-team' ),
				'default' => [
					'url' => 'www.instagram.com',
					'is_external' => true,
					'nofollow' => true,
					'custom_attributes' => '',
				],
			]
		);
		$repeater->end_controls_tab();
		$repeater->start_controls_tab(
			'mtt_style_tab',
			[
				'label' => esc_html__( 'Style', 'meet-the-team' ),
			]
		);
		$repeater->add_control(
			'mtt_box_name_style',
			[
				'label' => esc_html__( 'Name', 'meet-the-team' ),
				'type' => \Elementor\Controls_Manager::HEADING,
			]
		);
		$repeater->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'mtt_box_name_typography',
				'selector' => '{{WRAPPER}} {{CURRENT_ITEM}} .mtt-title',
			]
		);
		$repeater->add_control(
			'mtt_box_name_color',
			[
				'label' => esc_html__( 'Color', 'meet-the-team' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt-title' => 'color: {{VALUE}}',
				],
			]
		);
		$repeater->add_control(
			'mtt_box_profile_title_background_color',
			[
				'label' => esc_html__( 'Background', 'meet-the-team' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt-team-content .mtt-title' => 'background-color: {{VALUE}}',
				],
			]
		);
		$repeater->add_group_control(
			\Elementor\Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'mtt_title_shadow',
				'label' => esc_html__( 'Text Shadow', 'meet-the-team' ),
				'selector' => '{{WRAPPER}} {{CURRENT_ITEM}} .mtt-team-content .mtt-title',
				'default' => [
					'color' => 'transparent',
				]
			]
		);
		$repeater->add_control(
			'mtt_team_b',
			[
				'type' => Controls_Manager::DIVIDER,
			]
		);
		$repeater->add_control(
			'mtt_box_designation_heading',
			[
				'label' => esc_html__( 'Designation', 'meet-the-team' ),
				'type' => \Elementor\Controls_Manager::HEADING,
			]
		);
		$repeater->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'mtt_box_designation_typography',
				'selector' => '{{WRAPPER}} {{CURRENT_ITEM}} .mtt-post',
			]
		);
		$repeater->add_control(
			'mtt_box_designation_color',
			[
				'label' => esc_html__( ' Color', 'meet-the-team' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt-post' => 'color: {{VALUE}}',
				],
			]
		);
		$repeater->add_control(
			'mtt_box_profile_des_background_color',
			[
				'label' => esc_html__( 'Background', 'meet-the-team' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt-team-content .mtt-post' => 'background-color: {{VALUE}}',
				],
			]
		);
		$repeater->add_group_control(
			\Elementor\Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'mtt_designation_shadow',
				'label' => esc_html__( 'Text Shadow', 'meet-the-team' ),
				'selector' => '{{WRAPPER}} {{CURRENT_ITEM}} .mtt-team-content .mtt-post',
				'default' => [
					'color' => 'transparent',
				]
			]
		);

		$repeater->add_control(
			'mtt_team_c',
			[
				'type' => Controls_Manager::DIVIDER,
			]
		);

		
		$repeater->add_control(
			'mtt_box_profile_background_color',
			[
				'label' => esc_html__( 'Profile Image Background', 'meet-the-team' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt_team_profile_background, {{WRAPPER}} {{CURRENT_ITEM}} .mtt-pic::before, {{WRAPPER}} {{CURRENT_ITEM}} .mtt-team-style-26-team .mtt-team-content::before' => 'background-color: {{VALUE}}',
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt-portfolio-team .mtt-pic::before' => 'background: {{VALUE}}',
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt-team-section::before,{{WRAPPER}} {{CURRENT_ITEM}} .mtt-team-style-28-team:hover' => 'background: {{VALUE}}',
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt-team-section' => 'border: {{VALUE}}',
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt-team-thumble::after,{{WRAPPER}} {{CURRENT_ITEM}} .mtt-team-style-29-team::before' => 'background: {{VALUE}}',
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt-team-portfolio:after' => 'background: {{VALUE}}',
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt-team-our-box:hover, {{WRAPPER}} {{CURRENT_ITEM}} .mtt-team-style-30-team, {{WRAPPER}} {{CURRENT_ITEM}} .mtt-team-style-31-team' => 'background: {{VALUE}}',
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt-team-style-16-box::before' => 'background: {{VALUE}}',
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt-pic:after' => 'background-color: {{VALUE}}',
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt-team-style-20-team .mtt-pic' => 'border: {{VALUE}}',
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt-team-style-23-team' => 'background: {{VALUE}}',
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt-team-style-22-team, {{WRAPPER}} {{CURRENT_ITEM}} .mtt-team-style-21-team .mtt-pic::before' => 'background: {{VALUE}}',
				],
			]
		);

		$repeater->add_control(
			'mtt_team_d',
			[
				'type' => Controls_Manager::DIVIDER,
			]
		);

		// Icon One Style

		$repeater->add_control(
			'mtt_social_icon_one_style_switcher',
			[
				'label' => esc_html__( 'Social Icon One Style', 'meet-the-team' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'meet-the-team' ),
				'label_off' => esc_html__( 'Hide', 'meet-the-team' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
		$repeater->add_control(
			'mtt_team_social_icon_one_color',
			[
				'label' => esc_html__( 'Icon Color', 'meet-the-team' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt-social-icon-one i' => 'color: {{VALUE}}',
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt-social-icon-one svg' => 'fill: {{VALUE}}',
				],
				'condition' => [
					'mtt_social_icon_one_style_switcher' => 'yes',
				],
			]
		);
        $repeater->add_control(
			'mtt_team_social_icon_hover_one_color',
			[
				'label' => esc_html__( 'Icon Hover Color', 'meet-the-team' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt-social-icon-one i:hover' => 'color: {{VALUE}}',
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt-social-icon-one svg:hover' => 'fill: {{VALUE}}',
				],
				'condition' => [
					'mtt_social_icon_one_style_switcher' => 'yes',
				],
			]
		);
		$repeater->add_control(
			'mtt_box_icon_one_background_color',
			[
				'label' => esc_html__( 'Icon Background', 'meet-the-team' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} a.mtt-social-icon-one' => 'background-color: {{VALUE}}!important'
				],
				'condition' => [
					'mtt_social_icon_one_style_switcher' => 'yes',
				],
			]
		);
		$repeater->add_control(
			'mtt_box_icon_one_hover_background_color',
			[
				'label' => esc_html__( 'Icon Hover Background', 'meet-the-team' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} a.mtt-social-icon-one:hover' => 'background-color: {{VALUE}}!important'
				],
				'condition' => [
					'mtt_social_icon_one_style_switcher' => 'yes',
				],
			]
		);
		$repeater->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'mtt_box_icon_one_border',
				'selector' => '{{WRAPPER}} {{CURRENT_ITEM}} .mtt-social .mtt-social-icon-one',
				'condition' => [
					'mtt_social_icon_one_style_switcher' => 'yes',
				],
			]
		);

		// Icon Two Style
		$repeater->add_control(
			'mtt_social_icon_two_style_switcher',
			[
				'label' => esc_html__( 'Social Icon Two Style', 'meet-the-team' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'meet-the-team' ),
				'label_off' => esc_html__( 'Hide', 'meet-the-team' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
		$repeater->add_control(
			'mtt_team_social_icon_two_color',
			[
				'label' => esc_html__( 'Icon Color', 'meet-the-team' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt-social-icon-two i' => 'color: {{VALUE}}',
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt-social-icon-two svg' => 'fill: {{VALUE}}',
				],
				'condition' => [
					'mtt_social_icon_two_style_switcher' => 'yes',
				],
			]
		);
        $repeater->add_control(
			'mtt_team_social_icon_hover_two_color',
			[
				'label' => esc_html__( 'Icon Hover Color', 'meet-the-team' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt-social-icon-two i:hover' => 'color: {{VALUE}}',
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt-social-icon-two svg:hover' => 'fill: {{VALUE}}',
				],
				'condition' => [
					'mtt_social_icon_two_style_switcher' => 'yes',
				],
			]
		);
		$repeater->add_control(
			'mtt_box_icon_two_background_color',
			[
				'label' => esc_html__( 'Icon Background', 'meet-the-team' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}}  a.mtt-social-icon-two' => 'background-color: {{VALUE}}!important'
				],
				'condition' => [
					'mtt_social_icon_two_style_switcher' => 'yes',
				],
			]
		);
		$repeater->add_control(
			'mtt_box_icon_two_hover_background_color',
			[
				'label' => esc_html__( 'Icon Hover Background', 'meet-the-team' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}}  a.mtt-social-icon-two:hover' => 'background-color: {{VALUE}}!important'
				],
				'condition' => [
					'mtt_social_icon_two_style_switcher' => 'yes',
				],
			]
		);
		$repeater->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'mtt_box_icon_two_border',
				'selector' => '{{WRAPPER}} {{CURRENT_ITEM}} .mtt-social .mtt-social-icon-one',
				'condition' => [
					'mtt_social_icon_two_style_switcher' => 'yes',
				],
			]
		);

		// Icon Three Style

		$repeater->add_control(
			'mtt_social_icon_three_style_switcher',
			[
				'label' => esc_html__( 'Social Icon Three Style', 'meet-the-team' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'meet-the-team' ),
				'label_off' => esc_html__( 'Hide', 'meet-the-team' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
		$repeater->add_control(
			'mtt_team_social_icon_three_color',
			[
				'label' => esc_html__( 'Icon Color', 'meet-the-team' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt-social-icon-three i' => 'color: {{VALUE}}',
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt-social-icon-three svg' => 'fill: {{VALUE}}',
				],
				'condition' => [
					'mtt_social_icon_three_style_switcher' => 'yes',
				],
			]
		);
        $repeater->add_control(
			'mtt_team_social_icon_hover_three_color',
			[
				'label' => esc_html__( 'Icon Hover Color', 'meet-the-team' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt-social-icon-three i:hover' => 'color: {{VALUE}}',
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt-social-icon-three svg:hover' => 'fill: {{VALUE}}',
				],
				'condition' => [
					'mtt_social_icon_three_style_switcher' => 'yes',
				],
			]
		);
		$repeater->add_control(
			'mtt_box_icon_three_background_color',
			[
				'label' => esc_html__( 'Icon Background', 'meet-the-team' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} a.mtt-social-icon-three' => 'background-color: {{VALUE}}!important'
				],
				'condition' => [
					'mtt_social_icon_three_style_switcher' => 'yes',
				],
			]
		);
		$repeater->add_control(
			'mtt_box_icon_three_hover_background_color',
			[
				'label' => esc_html__( 'Icon Hover Background', 'meet-the-team' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} a.mtt-social-icon-three:hover' => 'background-color: {{VALUE}}!important'
				],
				'condition' => [
					'mtt_social_icon_three_style_switcher' => 'yes',
				],
			]
		);
		$repeater->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'mtt_box_icon_three_border',
				'selector' => '{{WRAPPER}} {{CURRENT_ITEM}} .mtt-social .mtt-social-icon-one',
				'condition' => [
					'mtt_social_icon_three_style_switcher' => 'yes',
				],
			]
		);

		// Icon Four Style

		$repeater->add_control(
			'mtt_social_icon_four_style_switcher',
			[
				'label' => esc_html__( 'Social Icon Four Style', 'meet-the-team' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'meet-the-team' ),
				'label_off' => esc_html__( 'Hide', 'meet-the-team' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
		$repeater->add_control(
			'mtt_team_social_icon_four_color',
			[
				'label' => esc_html__( 'Icon Color', 'meet-the-team' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt-social-icon-four i' => 'color: {{VALUE}}',
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt-social-icon-four svg' => 'fill: {{VALUE}}',
				],
				'condition' => [
					'mtt_social_icon_four_style_switcher' => 'yes',
				],
			]
		);
        $repeater->add_control(
			'mtt_team_social_icon_hover_four_color',
			[
				'label' => esc_html__( 'Icon Hover Color', 'meet-the-team' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt-social-icon-four i:hover' => 'color: {{VALUE}}',
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt-social-icon-four svg:hover' => 'fill: {{VALUE}}',
				],
				'condition' => [
					'mtt_social_icon_four_style_switcher' => 'yes',
				],
			]
		);
		$repeater->add_control(
			'mtt_box_icon_four_background_color',
			[
				'label' => esc_html__( 'Icon Background', 'meet-the-team' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} a.mtt-social-icon-four' => 'background-color: {{VALUE}}!important'
				],
				'condition' => [
					'mtt_social_icon_four_style_switcher' => 'yes',
				],
			]
		);
		$repeater->add_control(
			'mtt_box_icon_four_hover_background_color',
			[
				'label' => esc_html__( 'Hover Background', 'meet-the-team' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} a.mtt-social-icon-four:hover' => 'background-color: {{VALUE}}!important'
				],
				'condition' => [
					'mtt_social_icon_four_style_switcher' => 'yes',
				],
			]
		);
		$repeater->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'mtt_box_icon_four_border',
				'selector' => '{{WRAPPER}} {{CURRENT_ITEM}} .mtt-social .mtt-social-icon-one',
				'condition' => [
					'mtt_social_icon_four_style_switcher' => 'yes',
				],
			]
		);
		$repeater->add_control(
			'mtt_icon_bg_shape_color',
			[
				'label' => esc_html__( 'Shape Color', 'meet-the-team' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt_team_shape, {{WRAPPER}} {{CURRENT_ITEM}} .mtt-team .mtt-pic::before, {{WRAPPER}} {{CURRENT_ITEM}} .mtt-team-style-26-team .mtt-team-content' => 'background: {{VALUE}}',
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt-portfolio-team .mtt-pic::after, {{WRAPPER}} {{CURRENT_ITEM}} .mtt-team-style-27-team .mtt-team-content .mtt-title::before, {{WRAPPER}} {{CURRENT_ITEM}} .mtt-team-style-27-team .mtt-team-content .mtt-title::before' => 'background: {{VALUE}}',
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt-team-portfolio::before, {{WRAPPER}} {{CURRENT_ITEM}} .mtt-team-style-28-team::before' => 'background: {{VALUE}}',
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt-team-our-box-content::after' => 'background: {{VALUE}}',
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt-team-our-box::before, {{WRAPPER}} {{CURRENT_ITEM}} .mtt-team-style-29-team .mtt-team-content .mtt-inner-content' => 'background: {{VALUE}}',
					'{{WRAPPER}} {{CURRENT_ITEM}} .mtt-team-style-15-box:before' => 'background: {{VALUE}}',
				],
			]
		);
		$repeater->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'mtt_team_box_background',
				'label' => esc_html__( 'Background', 'meet-the-team' ),
				'types' => [ 'gradient' ],
				'selector' => '{{WRAPPER}} {{CURRENT_ITEM}} .mtt-six-number-bg, {{WRAPPER}} {{CURRENT_ITEM}} .mtt-total-team-box .mtt-social, {{WRAPPER}} {{CURRENT_ITEM}} .mtt-team-style-19-team::after, {{WRAPPER}} .mtt-team-style-19-team::before, {{WRAPPER}} {{CURRENT_ITEM}} .mtt-team-style-25-team, {{WRAPPER}} {{CURRENT_ITEM}} .mtt-pic:after, {{WRAPPER}} {{CURRENT_ITEM}} .mtt-team-style-27-team .mtt-team-content, {{WRAPPER}} {{CURRENT_ITEM}} .mtt-team-style-27-team .mtt-team-content:before,  {{WRAPPER}} {{CURRENT_ITEM}} .mtt-team-style-27-team .mtt-team-content:after',
			]
		);
		$repeater->end_controls_tab();
		$repeater->end_controls_tabs();
		$this->add_control(
			'mtt_box',
			[
				'label' => esc_html__( 'Meet The Team', 'meet-the-team' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'mtt_box_name' => esc_html__( 'Jhon Doe', 'meet-the-team' ),
					],
					[
						'mtt_box_name' => esc_html__( 'Smith Jhon', 'meet-the-team' ),
					],
					[
						'mtt_box_name' => esc_html__( 'Robin Smith', 'meet-the-team' ),
					],
					[
						'mtt_box_name' => esc_html__( 'Json Doe', 'meet-the-team' ),
					],
				],
				'title_field' => `{{{ mtt_box_name }}}`,
			]
		);
		$this->add_responsive_control(
			'mtt_team__the_social_icon_size',
			[
				'label' => esc_html__( 'Social Icon Size', 'meet-the-team' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'devices' => [ 'desktop', 'laptop', 'tablet', 'tablet_extra', 'mobile', 'mobile_extra' ],
				'selectors' => [
					'{{WRAPPER}} .mtt-social-icon-one i' => 'font-size: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .mtt-social-icon-two i' => 'font-size: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .mtt-social-icon-three i' => 'font-size: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .mtt-social-icon-four i' => 'font-size: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .mtt-social-icon-one svg' => 'inline-size: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .mtt-social-icon-two svg' => 'inline-size: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .mtt-social-icon-three svg' => 'inline-size: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .mtt-social-icon-four svg' => 'inline-size: {{SIZE}}{{UNIT}};',
				],
			]
		);
		$this->add_responsive_control(
			'mtt_team__the_social_icon_round_size',
			[
				'label' => esc_html__( 'Icon Round Size', 'meet-the-team' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .mtt-social a' => 'inline-size: {{SIZE}}{{UNIT}}!important; block-size: {{SIZE}}{{UNIT}}!important;',
				],
			]
		);
		$this->end_controls_section();

		$this->start_controls_section(
			'mtt_team_style_section',
			[
				'label' => esc_html__( 'Team Style', 'meet-the-team' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'mtt_team_box_background',
				'label' => esc_html__( 'Background', 'meet-the-team' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .mtt-total-team-box',
			]
		);
		$this->add_responsive_control(
            'mtt_team_the_box_margin',
            [
                'label' => esc_html__('Margin', 'meet-the-team'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .mtt-total-team-box' => 'margin-block: {{TOP}}{{UNIT}} {{BOTTOM}}{{UNIT}}; margin-inline: {{LEFT}}{{UNIT}} {{RIGHT}}{{UNIT}};',
                ],
            ]
        );
		$this->add_responsive_control(
            'mtt_team_the_box_padding',
            [
                'label' => esc_html__('Padding', 'meet-the-team'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .mtt-total-team-box' => 'padding-block: {{TOP}}{{UNIT}} {{BOTTOM}}{{UNIT}}; padding-inline: {{LEFT}}{{UNIT}} {{RIGHT}}{{UNIT}};',
                ],
            ]
        );
		$this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'mtt_team_the_box_border',
				'selector' => '{{WRAPPER}} .mtt-total-team-box',
			]
		);
		$this->add_responsive_control(
			'mtt_team_the_box_border_radius',
			[
				'label' => esc_html__( 'Border Radius', 'meet-the-team' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .mtt-total-team-box' => 'border-radius: {{SIZE}}{{UNIT}};',
				],
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'mtt_team_the_box_box_shadow',
				'selector' => '{{WRAPPER}} .mtt-total-team-box',
			]
		);
		$this->end_controls_section();

	}
	protected function render() {
		$settings = $this->get_settings_for_display();
		$column_align = $settings['mtt_team_box_align'];
		$mtt_styles_no = $settings['mtt_style_selection'];

		// Social Link
		if ( ! empty( $settings['mtt_social_icon_one_link']['url'] ) ) {
			$this->add_link_attributes( 'mtt_social_icon_one_link', $settings['mtt_social_icon_one_link'] );
		}
		if ( ! empty( $settings['mtt_social_icon_two_link']['url'] ) ) {
			$this->add_link_attributes( 'mtt_social_icon_two_link', $settings['mtt_social_icon_two_link'] );
		}
		if ( ! empty( $settings['mtt_social_icon_three_link']['url'] ) ) {
			$this->add_link_attributes( 'mtt_social_icon_three_link', $settings['mtt_social_icon_three_link'] );
		}
		if ( ! empty( $settings['mtt_social_icon_four_link']['url'] ) ) {
			$this->add_link_attributes( 'mtt_social_icon_four_link', $settings['mtt_social_icon_four_link'] );
		}

			if( $mtt_styles_no ){?>
				<div class="mtt-team-area-<?php echo $mtt_styles_no ?>">
					<div class="bwd-container-fluid">
						<div class="bwd-row mtt_gapr <?php echo $column_align; ?>">
					<?php
						if ( $settings['mtt_box'] ) {
							foreach (  $settings['mtt_box'] as $item ) {
						echo '<div class="column_number mtt_gapc bwd-col-lg-3 bwd-col-md-6 bwd-col-sm-6 elementor-repeater-item-' . esc_attr( $item['_id'] ) . '">'; ?>
							<div class="mtt-our-team-box mtt-total-team-box">

								<?php if( $mtt_styles_no == '2' ){?> <div class="mtt-our-team-item"> <?php } ?>

								<div class="mtt-pic mtt_team_profile_background">
									<img src="<?php echo esc_url($item['mtt_team_profile_image']['url']); ?>" alt="bestwpdeveloper">
									
									<?php if( $mtt_styles_no == '27' ){?> <div class="bwd-img-layer"></div> <?php } ?>

									<!-- image social -->
									<?php $allowed_styles1 = array('3', '4', '18', '26'); if (in_array($mtt_styles_no, $allowed_styles1)) { include 'common/social.php'; } ?>

								</div>

								<!-- middle social -->
								<?php $allowed_styles2 = array('6', '9', '20', '21', '25'); if (in_array($mtt_styles_no, $allowed_styles2)) { include 'common/social.php'; } ?>

								<?php if( $mtt_styles_no == '11' ){?> <div class="mtt-team-our-box-content"> <?php } ?>

								<div class="mtt-team-content">

									<?php if( $mtt_styles_no == '21' ){?> <div class="mtt-info"> <?php } ?>

										<?php if( $mtt_styles_no == '16' ){ include 'common/social.php'; }?>

										<div class="mtt-title mtt-titleee"><?php echo esc_html($item['mtt_box_name']); ?></div>
										<div class="mtt-post"><?php echo $item['mtt_box_designation']; ?></div>

										<!-- Content social -->
										<?php $allowed_styles3 = array('2', '5', '7', '10', '14', '15', '17', '19', '24', '27'); if (in_array($mtt_styles_no, $allowed_styles3)) { include 'common/social.php'; } ?>

									<?php if( $mtt_styles_no == '21' ){?> </div> <?php } ?>

								</div>

								<!-- bottom social -->
								<?php $allowed_styles4 = array('1', '8', '11', '12', '13', '22', '23', '28', '29', '30', '31'); if (in_array($mtt_styles_no, $allowed_styles4)) { include 'common/social.php'; } ?>

								<?php if( $mtt_styles_no == '11' ){?> </div> <?php } ?>

								<?php if( $mtt_styles_no == '2' ){?> </div> <?php } ?>
							</div>
						</div>
						<?php
							}
						}
						?>
					</div>
				</div>
			</div>
			<?php
			}
	}
}
